Shortcut to print out .png and .pdf figures at a high resolution to project subfolder.
Usage
pprint(
p,
file = NULL,
dpi = 540,
overwrite = FALSE,
folder = "02 Results/Figures",
...
)
Arguments
- p
Figure to print.
- file
Output figure name.
- dpi
Dots per inch.
- overwrite
Logical to replace existing file or not if it exists.
- folder
Output figure subfolder (assuming standardised project folder structure).
Examples
if (FALSE) { # \dontrun{
} # }